 /*
 * file      : utils.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
/*#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <stdlib.h>*/
#include <string.h>

#include "libbasebuild.h"



// TRUE SI LE FICHIER EXISTE SINON FALSE
//
gboolean libutils_test_file_exist (gchar *File)
{
	/*struct stat status;
	gint	    ret;
	ret = stat (File, &status);
	return (ret > -1 && S_ISREG (status.st_mode));*/
	return (g_file_test (File, G_FILE_TEST_IS_REGULAR));
}
// TRUE SI LE DOSSIER EXISTE SINON FALSE
//
gboolean libutils_test_dir_exist (gchar *File)
{
	/*struct stat status;
	gint	    ret;
	ret = stat (File, &status);
	return (ret > -1 && S_ISDIR (status.st_mode));*/
	return (g_file_test (File, G_FILE_TEST_IS_DIR));
}
// TRUE SI p_dest EST DANS p_src SINON FALSE
//
gboolean libutils_new_strcmp (gchar *p_src, gchar *p_dest)
{
	gint	len_aiguille = strlen (p_dest);
	gint	len_meule;
	gint	len;
	gchar	*PtrBeginSrc = NULL;
	gchar	*PtrEndSrc = NULL;
	gchar	*PtrSrc = NULL;
	gchar	*PtrDest = p_dest;
	
	for (PtrBeginSrc = p_src; *PtrBeginSrc == ' ' || *PtrBeginSrc == '\t'; PtrBeginSrc ++);
	for (PtrEndSrc = PtrBeginSrc; *PtrEndSrc != ' ' && *PtrEndSrc != '\t'; PtrEndSrc ++);
	len_meule = PtrEndSrc - PtrBeginSrc;
	
	if (len_meule != len_aiguille) return (FALSE);
	
	len = 0;
	for (PtrSrc = PtrBeginSrc; PtrSrc < PtrEndSrc; PtrSrc ++, PtrDest ++) {
		if (*PtrSrc != *PtrDest) return (FALSE);;
		len ++;
	}
	
	return (len_meule == len ? TRUE : FALSE);
	
}
// AFFICHE L ICONE A GAUCHE DANS LA BARRE DE TITRE
// 
void libutils_set_default_icone_to_win (GtkWidget *win)
{
	gchar     *LineCommand = NULL;
	GError    *error = NULL;

	LineCommand = g_strdup_printf ("%s/pixmaps/basebuild.png", PACKAGE_DATA_DIR);
	if (TRUE == libutils_test_file_exist (LineCommand)) {
		// LineCommand = g_strdup ("/home/cat/Projects/basebuild-0.0.4/pixmaps/basebuild.png");
	 	gtk_window_set_icon_from_file (GTK_WINDOW(win), LineCommand, &error);
	 	if (error) {
	 		GDK_PIXBUF_ERROR;
			g_critical ("Could not load pixbuf: %s\n", error->message);
			g_error_free (error);
		}
	}
	g_free (LineCommand);
	LineCommand = NULL;
}
// Execute WHICH Name_Prg et si 'gchar **Pathname_Prg' est non null retourne le resultat
// 
gboolean libutils_find_file (gchar *p_find_file)
{
	gchar      *PathName = NULL;
	gboolean    BoolFind = FALSE;
	
	if (NULL == p_find_file) return (FALSE);
	if ('\0' == *p_find_file) return (FALSE);
	
	PathName = g_strdup_printf ("/usr/bin/%s", p_find_file);
	BoolFind = libutils_test_file_exist (PathName);
	g_free (PathName);
	PathName = NULL;
	if (TRUE == BoolFind) return (TRUE);
	
	PathName = g_strdup_printf ("/usr/sbin/%s", p_find_file);
	BoolFind = libutils_test_file_exist (PathName);
	g_free (PathName);
	PathName = NULL;
	if (TRUE == BoolFind) return (TRUE);
	
	PathName = g_strdup_printf ("/usr/local/bin/%s", p_find_file);
	BoolFind = libutils_test_file_exist (PathName);
	g_free (PathName);
	PathName = NULL;
	if (TRUE == BoolFind) return (TRUE);
	
	return (FALSE);
}
// 
// 
size_t libutils_get_size_file (char *PathName)
{
	FILE   *fp;
	size_t  size = 0;

	if ((fp = fopen (PathName, "r"))) {
		fseek (fp, 0, SEEK_END);
		size = ftell (fp);
		fclose (fp);
	}
	return (size);
}
// 
// Algo retravaille depuis:
//	C EN ACTION - 2 ieme Edition - Yves Mettier
// 
gboolean libutils_copy_src_to_dest (gchar *filesrc, gchar *filedest)
{
	FILE	*fn = NULL;
	FILE	*fe = NULL;
	gchar	buf [ BUFSIZ ];
	size_t	size = libutils_get_size_file (filesrc);
	gulong	blk;
	gulong	cpt;
	
	if (0 == size) {
		fprintf (stderr, "La taille de : %s est NULLE !!!\n", filesrc);
		return (FALSE);
	}
	if (NULL == (fe = fopen (filesrc, "r"))) {
		fprintf (stderr, "Echec ouverture en lecture de: %s\n", filesrc);
		return (FALSE);
	}
	if (NULL == (fn = fopen (filedest, "w"))) {
		fprintf (stderr, "Echec ouverture en ecriture de: %s\n", filedest);
		fclose (fe);
		return (FALSE);
	}
	
	blk = size / BUFSIZ;
	
	g_print ("\t%s\n\t%s\n", filesrc, filedest);
	cpt = 0;
	while ( ! feof (fe)) {
		size_t	l;
		
		l = fread (buf, sizeof (*buf), BUFSIZ, fe);
		if (ferror (fe)) {
			fprintf (stderr, "Erreur de lecture\n");
			fclose (fn);
			fclose (fe);
			return (FALSE);
		}
		fwrite (buf, sizeof (*buf), l, fn);
		if (ferror (fn)) {
			fprintf (stderr, "Erreur d'ecriture\n");
			fclose (fn);
			fclose (fe);
			return (FALSE);
		}
		
		cpt ++;
	}
	fclose (fn);
	fclose (fe);
	
	return (TRUE);
}




















