 /*
 * file      : configuser.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <stdlib.h>

#include "../libbasebuild/libbasebuild.h"
#include "global.h"
#include "configuser.h"



VAR_CONFIG Config = {
	FALSE,		// BoolConfigOk
	NULL,		// Path
	NULL,		// PathGlade
	NULL,		// NameFileGlade
	NULL,		// NameProject
	0,		// WinPos_X
	0,		// WinPos_Y
	750,		// WinWidth
	680,		// WinHeight
	0		// Page

};


// AFFICHE LES DATAS
// 
void config_print_data (gchar *p_str)
{
	gint	len = strlen (p_str);
	g_print("%s", p_str);
	while (len < 33) {
		g_print(" ");
		len ++;
	}
	g_print("= ");
}
// RETOURNE LE NOM COMPLET DU FICHIER DE CONFIGURATION
// 
gchar *config_get_pathname (void)
{
	return ((gchar *)g_strdup_printf ("%s/%s", getenv ("HOME"), ".config/basebuild/basebuild.conf"));
}
// RETOURNE UNE DEFINITION DU FICHIER DE CONFIGURATION
// 
gchar *config_get_target (gchar *p_buf)
{
	gchar	*Str = NULL;
	gchar	*Ptr = NULL;
	
	if ((Ptr = strchr (p_buf, '=')) != NULL) {
		Ptr ++;
		while (*Ptr && (*Ptr != ' ' && *Ptr != '\t')) Ptr ++;
		Ptr ++;
		Str = g_strdup (Ptr);
		if ((Ptr = strchr (Str, '\r')) != NULL) *Ptr = '\0';
		if ((Ptr = strchr (Str, '\n')) != NULL) *Ptr = '\0';
	}
	return ((gchar *)Str);
}
// LECTURE VALEUR BOOLEAN
// 
gboolean config_get_bool (gchar *value)
{
	gchar *ptr = value;

	while (*ptr) {
		*ptr = toupper (*ptr);
		ptr++;
	}
	return (!strncmp (value, "TRUE", strlen ("TRUE")) ? TRUE : FALSE);
}
// LECTURE STRING
// 
gboolean config_read_value_str (gchar *p_Buf, gchar *p_Search, gchar **p_ValueStr)
{
	gchar	*Ptr = NULL;
	if (libutils_new_strcmp (p_Buf, p_Search) == TRUE) {
		if ((Ptr = config_get_target (p_Buf)) != NULL) {
			*p_ValueStr = g_strdup (Ptr);
			g_free (Ptr);
			Ptr = NULL;
			config_print_data (p_Search);
			g_print("%s\n",*p_ValueStr ? *p_ValueStr : "");
			return (TRUE);	
		}
	}
	return (FALSE);	
}
// LECTURE BOOLEAN
// 
gboolean config_read_value_bool (gchar *p_Buf, gchar *p_Search, gboolean *p_ValueBool)
{	
	gchar	*Ptr = NULL;
	if (libutils_new_strcmp (p_Buf, p_Search) == TRUE) {
		if ((Ptr = config_get_target (p_Buf)) != NULL) {
			*p_ValueBool = config_get_bool (Ptr);
			g_free (Ptr);
			Ptr = NULL;
			config_print_data (p_Search);
			g_print("%s\n",*p_ValueBool ? "TRUE" : "FALSE");
			return (TRUE);	
		}
	}
	return (FALSE);	
}
// LECTURE NUMERIQUE
// 
gboolean config_read_value_atoi (gchar *p_Buf, gchar *p_Search, gint *p_ValueAtoi, gint p_Min, gint p_Max)
{
	gchar	*Ptr = NULL;
	if (libutils_new_strcmp (p_Buf, p_Search) == TRUE) {
		if ((Ptr = config_get_target (p_Buf)) != NULL) {
			*p_ValueAtoi = atoi (Ptr);
			g_free (Ptr);
			Ptr = NULL;
			if (p_Min > -1 && *p_ValueAtoi < p_Min) *p_ValueAtoi = p_Min;
			if (p_Max > -1 && *p_ValueAtoi > p_Max) *p_ValueAtoi = p_Max;
			config_print_data (p_Search);
			g_print("%d\n",*p_ValueAtoi);
			return (TRUE);
		}
	}
	return (FALSE);	
}
// LECTURE PATHNAME
// 
gboolean config_read_value_path (gchar *p_Buf, gchar *p_Search, gchar **p_ValuePath, gchar *p_default)
{
	gchar	*Ptr = NULL;
	if (libutils_new_strcmp (p_Buf, p_Search) == TRUE) {
		if ((Ptr = config_get_target (p_Buf)) != NULL) {
			if (libutils_test_dir_exist (Ptr) == TRUE) {
				*p_ValuePath = Ptr;
			} else {
				if (NULL == p_default)	*p_ValuePath = getenv ("HOME");
				else			*p_ValuePath = g_strdup (p_default);
				g_free (Ptr);
				Ptr = NULL;
			}
		}
		else {
			if (NULL == p_default)	*p_ValuePath = getenv ("HOME");
			else			*p_ValuePath = g_strdup (p_default);
		}
		config_print_data (p_Search);
		g_print("%s\n",*p_ValuePath);
		return (TRUE);
	}
	return (FALSE);	
}
// LECTURE DU FICHIER DE CONFIGURATION
// 
void config_read (void)
{
	gchar	*PathNameConfig = config_get_pathname ();
	FILE	*fp;
#define MAX_CARS 255
	gchar	 buf   [ MAX_CARS +1 ];
	
	g_print ("\n------------------------------------------------------------------------\n");
	g_print ("%s\n", PathNameConfig);
	g_print ("------------------------------------------------------------------------\n");
	if (libutils_test_file_exist (PathNameConfig) == FALSE) {
		
		gchar	*StrDir = g_strdup (PathNameConfig);
		gchar	*Ptr = strrchr (StrDir, '/');
		
		Ptr ++;
		*Ptr = '\0';
		g_mkdir_with_parents (StrDir, 0700);
		g_free (StrDir);
		StrDir = Ptr = NULL;
		
		config_save ();
	}
	
	fp = fopen (PathNameConfig, "r");
	while (fgets (buf, MAX_CARS, fp) != NULL) {
		
		// Si commentaire ou ligne vide alors ligne suivante
		if (buf[0] == '#' || buf[0] == '\n') continue;

		// READ ATOI
		// 
		if (!config_read_value_atoi (buf, "WIN_POS_X",			&Config.WinPos_X,        0,	-1));
		if (!config_read_value_atoi (buf, "WIN_POS_Y",			&Config.WinPos_Y,        0,	-1));
		if (!config_read_value_atoi (buf, "WIN_WIDTH",			&Config.WinWidth,       -1,	-1));
		if (!config_read_value_atoi (buf, "WIN_HEIGHT",			&Config.WinHeight,      -1,	-1));
		if (!config_read_value_atoi (buf, "PAGE_NOTEBOOK",		&Config.Page,       	-1,	-1));
		if (!config_read_value_atoi (buf, "VERSION_A",			&Config.Version_A,      -1,	-1));
		if (!config_read_value_atoi (buf, "VERSION_B",			&Config.Version_B,      -1,	-1));
		if (!config_read_value_atoi (buf, "VERSION_C",			&Config.Version_C,      -1,	-1));
		
		// READ BOOL
		// 
		
		// READ PATH
		// 
		if (!config_read_value_path (buf, "PATH",			&Config.Path,		NULL));
		if (!config_read_value_path (buf, "PATH_GLADE",			&Config.PathGlade,	NULL));
		
		// READ STRING
		// 
		if (!config_read_value_str (buf, "NAME_PROJECT",		&Config.NameProject));
		if (!config_read_value_str (buf, "NAMEFILE_GLADE",		&Config.NameFileGlade));
		
		buf [ 0 ] = '\0';
	}
	fclose (fp);
}
//  SAUVEGARDE DU FICHIER DE CONFIGURATION
// 
void config_save (void)
{
	gchar	*PathNameConfig = config_get_pathname ();
	FILE	*fp;
	
	g_print ("PathNameConfig = %s\n", PathNameConfig);
	if (NULL != (fp = fopen (PathNameConfig, "w"))) {
		fprintf (fp,   "############################################################################\n");
		fprintf (fp,   "## Fichier de configuration pour : %s\n", PACKAGE_STRING);
		fprintf (fp,   "##--------------------------------------------------------------------------\n");
		fprintf (fp,   "## File of configuration to : %s\n", PACKAGE_STRING);
		fprintf (fp,   "############################################################################\n");
		
		fprintf (fp, "\n");
		fprintf (fp, "PATH             = %s\n", Config.Path == NULL ? getenv ("HOME") : Config.Path);
		fprintf (fp, "PATH_GLADE       = %s\n",	Config.PathGlade == NULL ? "" : Config.PathGlade);
		fprintf (fp, "NAMEFILE_GLADE   = %s\n",	Config.NameFileGlade == NULL ? "" : Config.NameFileGlade);
		fprintf (fp, "NAME_PROJECT     = %s\n", Config.NameProject == NULL ? "NameProject" : Config.NameProject);
		fprintf (fp, "WIN_POS_X        = %d\n", Config.WinPos_X);
		fprintf (fp, "WIN_POS_Y        = %d\n", Config.WinPos_Y);
		fprintf (fp, "WIN_WIDTH        = %d\n", Config.WinWidth);
		fprintf (fp, "WIN_HEIGHT       = %d\n", Config.WinHeight);
		fprintf (fp, "PAGE_NOTEBOOK    = %d\n", Config.Page);
		fprintf (fp, "VERSION_A        = %d\n", Config.Version_A);
		fprintf (fp, "VERSION_B        = %d\n", Config.Version_B);
		fprintf (fp, "VERSION_C        = %d\n", Config.Version_C);
		
		fprintf (fp, "\n");
		fclose (fp);
	}
}
// LIBERATION MEMOIRE
// 
void config_remove (void)
{
	g_free (Config.Path);
	Config.Path = NULL;
	g_free (Config.NameProject);
	Config.NameProject = NULL;
	g_free (Config.PathGlade);
	Config.PathGlade = NULL;
	g_free (Config.NameFileGlade);
	Config.NameFileGlade = NULL;
}































